@@ -5,7 +5,7 @@ import pandas as pd
 
 from tradingfeatures import bitfinex
 from tradingfeatures import bitstamp
-from tradingfeatures import bitmex
+from tradingfeatures import bitmex, bitmex_v2
 from tradingfeatures import google_trends
 
 
@@ -16,12 +16,13 @@ class base:
         self.bitfinex_wrong = bitfinex(wrong_columns=True)      # Wrong order, keeping for old saved models
         self.bitstamp = bitstamp()
         self.bitmex = bitmex()
+        self.bitmex_v2 = bitmex_v2()
         self.google_trends = google_trends()
 
         self.columns = ['open', 'low', 'high', 'close', 'volume']
         self.columns_final = ['close', 'low', 'high', 'volume', 'fundingRate']
 
-    def eval_get(self, limit=1000, wrong_columns=False):
+    def eval_get(self, limit=1000, new_api=False, wrong_columns=False):
         if wrong_columns:
             df_bitfinex = self.bitfinex_wrong.get(10000).set_index('timestamp')
         else:
@@ -32,12 +33,11 @@ class base:
         self.df1_updated = df_bitfinex[-limit:]
         self.df2_updated = df_bitstamp[-limit:]
 
-        merged = self.uber_get(save=False, update=True, fundings=True, trends=False)        
+        merged = self.uber_get(save=False, update=True, fundings=True, trends=False, new_api=new_api)        
 
         return merged
-        # return merged[self.columns_final].to_numpy()
         
-    def uber_get(self, path='', fundings=False, trends=False, date=True, save=True, update=False):
+    def uber_get(self, path='', fundings=False, trends=False, date=True, save=True, update=False, new_api=False):
         if update:
             df1 = self.df1_updated
             df2 = self.df2_updated
@@ -48,6 +48,7 @@ class base:
 
         # df1.index = df1.index.astype(int)       # fix this in bitfinex later
 
+        # Do not use moving hour
         df1 = df1[self.columns].loc[:self.current_time()-1]
         df2 = df2[self.columns].loc[:self.current_time()-1]
         
@@ -73,9 +74,16 @@ class base:
             final_columns = self.columns
             final_columns.append('fundingRate')
         
-            df_bitmex = self.bitmex.get_funding_rates(save_csv=False)
-            
-            merged = self.bitmex.price_funding_merger(df_final, df_bitmex)
+            if new_api:
+                start_timestamp = df_final.index[0]
+                df_bitmex = self.bitmex_v2.get_fundings(start_timestamp)  
+                merged, df_bitmex = self.bitmex_v2.price_funding_merger(df_final, df_bitmex)
+                if save:
+                    df_bitmex.to_csv(path + '/bitmex_fundings.csv')
+            else:
+                df_bitmex = self.bitmex.get_funding_rates(save_csv=False)            
+                merged = self.bitmex.price_funding_merger(df_final, df_bitmex)
+
             df_final = merged[final_columns]
 
         if trends:
